@@ -5,16 +5,9 @@ import os,sys
 import requests
 import pandas as pd
 import json
-
 import random
 import datetime,time
 import logging
-logging.basicConfig(level=logging.DEBUG)
-
-# pd.set_option('display.max_columns', None)  # or 1000
-# pd.set_option('display.max_rows', None)  # or 1000
-# pd.set_option('display.max_colwidth', -1)  # or 199
-# pd.options.mode.chained_assignment = None  # default='warn' https://stackoverflow.com/questions/20625582/how-to-deal-with-settingwithcopywarning-in-pandas
 
 mode ='local'
 
@@ -47,14 +40,22 @@ if(mode=='local'):
 run_time=datetime.datetime.now()
 
 #Constants
-indices = ['NIFTY','NIFTYIT','BANKNIFTY']
+indices = ['NIFTY','FINNIFTY','BANKNIFTY']
+
+
+
+
+
+
+
+
+
 
 def running_status():
     start_now=datetime.datetime.now().replace(hour=9, minute=15, second=0, microsecond=0)
-    end_now=datetime.datetime.now().replace(hour=15, minute=45, second=0, microsecond=0)
+    end_now=datetime.datetime.now().replace(hour=15, minute=30, second=0, microsecond=0)
     return start_now<datetime.datetime.now()<end_now
 
-
 #Getting FNO Symboles
 def fnolist():
     # df = pd.read_csv("https://www1.nseindia.com/content/fo/fo_mktlots.csv")
@@ -83,33 +84,6 @@ def nse_optionchain_scrapper(symbol):
     return payload
 
 
-def oi_data_builder():
-    oi_data = pd.DataFrame()
-    symbols=fnolist()
-
-    for i, symbol in enumerate(symbols):
-        #if(i>4):break #Tester
-        logging.info("Fetching: "+symbol)
-        payload = nse_optionchain_scrapper(symbol)
-
-        m=0
-        for m in range(len(payload['records']['data'])):
-            try:
-                try:
-                    payload['records']['data'][m]['PE']['Type']='PE'
-                    oi_data = oi_data.append(payload['records']['data'][m]['PE'],ignore_index=True)
-                except:
-                    pass
-                try:
-                    payload['records']['data'][m]['CE']['Type']='CE'
-                    oi_data = oi_data.append(payload['records']['data'][m]['CE'],ignore_index=True)
-                except:
-                    pass
-            except:
-                logging.info(m)
-
-    return oi_data
-
 def oi_chain_builder (symbol,expiry="latest",oi_mode="full"):
 
     payload = nse_optionchain_scrapper(symbol)
@@ -244,40 +218,6 @@ def nse_quote_ltp(symbol,expiryDate="latest",optionType="-",strikePrice=0):
   # print(nse_quote_ltp("BANKNIFTY","13-Aug-2020","PE",21000))
   # print(nse_quote_ltp("RELIANCE","latest","PE",2300))
 
-def nse_quote_meta(symbol,expiryDate="latest",optionType="-",strikePrice=0):
-  payload = nse_quote(symbol)
-  #https://stackoverflow.com/questions/7961363/removing-duplicates-in-lists
-  #https://stackoverflow.com/questions/19199984/sort-a-list-in-python
-  if(expiryDate=="latest") or (expiryDate=="next"):
-    if(optionType!="Fut"):
-      dates=list(set((payload["expiryDates"])))
-      dates.sort(key = lambda date: datetime.datetime.strptime(date, '%d-%b-%Y'))
-      expiryDate=dates[0]
-      if(expiryDate=="next"):expiryDate=dates[1]
-
-  meta = "Options"
-  if(optionType=="Fut"): meta = "Futures"
-  if(optionType=="PE"):optionType="Put"
-  if(optionType=="CE"):optionType="Call"
-
-  if(optionType!="-"):
-      for i in payload['stocks']:
-        if meta in i['metadata']['instrumentType']:
-          #print(i['metadata'])
-          if(expiryDate=="latest"):
-            metadata = i['metadata']
-            break
-
-          if (i['metadata']["expiryDate"]==expiryDate):
-            if (i['metadata']["optionType"]==optionType):
-              if (i['metadata']["strikePrice"]==strikePrice):
-                metadata = i['metadata']
-
-  if(optionType=="-"):
-      metadata = payload['info']
-
-  return metadata
-
 def nse_optionchain_ltp(payload,strikePrice,optionType,inp=0,intent=""):
     expiryDate=payload['records']['expiryDates'][inp]
     for x in range(len(payload['records']['data'])):
@@ -354,6 +294,6 @@ def nse_past_results(symbol):
 
 def expiry_list(symbol):
     logging.info("Getting Expiry List of: "+ symbol)
-    payload = nse_optionchain_scrapper(symbol,)
+    payload = nse_optionchain_scrapper(symbol)
     payload = pd.DataFrame({'Date':payload['records']['expiryDates']})
-    return
+    return payload
